@@ -46,7 +46,6 @@ fn main() {
 */
 #[macro_use]
 extern crate lazy_static;
-extern crate pest_derive;
 
 macro_rules! regexp {
     ($($arg:tt)*) => {{
@@ -61,6 +60,7 @@ macro_rules! regexp {
     }};
 }
 
+#[macro_export]
 macro_rules! map {
     {$($key:expr => $value:expr),+} => {{
         let mut m = HashMap::new();
@@ -71,37 +71,57 @@ macro_rules! map {
     }};
 }
 
-extern crate pest;
-
 mod code;
 mod fullwidth;
 mod halfwidth;
 mod strategery;
 
-mod csharp;
-mod css;
-mod dart;
-mod go;
-mod html;
-mod java;
-mod javascript;
-mod json;
-mod kotlin;
-mod markdown;
-mod objective_c;
-mod php;
-mod python;
-mod ruby;
-mod rust;
-mod sql;
-mod swift;
-mod yaml;
+#[doc(hidden)]
+pub mod csharp;
+#[doc(hidden)]
+pub mod css;
+#[doc(hidden)]
+pub mod dart;
+#[doc(hidden)]
+pub mod elixir;
+#[doc(hidden)]
+pub mod go;
+#[doc(hidden)]
+pub mod html;
+#[doc(hidden)]
+pub mod java;
+#[doc(hidden)]
+pub mod javascript;
+#[doc(hidden)]
+pub mod json;
+#[doc(hidden)]
+pub mod kotlin;
+#[doc(hidden)]
+pub mod markdown;
+#[doc(hidden)]
+pub mod objective_c;
+#[doc(hidden)]
+pub mod php;
+#[doc(hidden)]
+pub mod python;
+#[doc(hidden)]
+pub mod ruby;
+#[doc(hidden)]
+pub mod rust;
+#[doc(hidden)]
+pub mod scala;
+#[doc(hidden)]
+pub mod sql;
+#[doc(hidden)]
+pub mod strings;
+#[doc(hidden)]
+pub mod swift;
+#[doc(hidden)]
+pub mod yaml;
 
 use crate::strategery::Strategery;
-use code::Results;
+pub use code::{FormatResult, LintResult, Results};
 use regex::Regex;
-use std::ffi::OsStr;
-use std::path::Path;
 
 lazy_static! {
     static ref FULL_DATE_RE: Regex = regexp!(
@@ -111,20 +131,25 @@ lazy_static! {
     static ref CJK_RE: Regex = regexp!("{}", r"\p{CJK}");
     static ref SPACE_RE: Regex = regexp!("{}", r"[ ]");
     static ref DASH_HANS_RE: Regex = regexp!("{}", r"([\p{CJK}）】」》”’])([\-]+)([\p{CJK}}}（【「《“‘])");
+    // （）【】「」《》
     static ref LEFT_QUOTE_RE: Regex = regexp!("{}", r" ([（【「《])");
     static ref RIGHT_QUOTE_RE: Regex = regexp!("{}", r"([）】」》]) ");
     // Strategies all rules
     static ref STRATEGIES: Vec<Strategery> = vec![
-        // EnglishLetter
-        Strategery::new(r"\p{CJK}", r"[a-zA-Z]", true, true),
-        // Number
-        Strategery::new(r"\p{CJK}", r"[0-9]", true, true),
+        // EnglishLetter, Number
+        // But not start with %, $, \ for avoid change %s, %d, $1, $2, \d, \r, \p ... in source code
+        Strategery::new(r"\p{CJK}[^%\$\\]", r"[a-zA-Z0-9]", true, false),
+        Strategery::new(r"[^%\$\\][a-zA-Z0-9]", r"\p{CJK}", true, false),
+        // 10%中文
+        Strategery::new(r"[0-9][%]", r"\p{CJK}", true, false),
         // SpecialSymbol
         Strategery::new(r"\p{CJK}", r"[\|+*]", true, true),
+        // @ after CJK, not not before, 你好 @某某
         Strategery::new(r"\p{CJK}", r"[@]", true, false),
         Strategery::new(r"\p{CJK}", r"[\[\(‘“]", true, false),
-        Strategery::new(r"[’”\]\)!%]", r"\p{CJK}", true, false),
-        // FullwidthPunctuation
+        Strategery::new(r"[’”\]\)!]", r"\p{CJK}", true, false),
+
+        // FullwidthPunctuation remove space case, Fullwidth can safe to remove spaces
         Strategery::new(r"[\w\p{CJK}]", r"[，。！？：；）」》】”’]", false, true),
         Strategery::new(r"[‘“【「《（]", r"[\w\p{CJK}]", false, true),
     ];
@@ -214,20 +239,6 @@ fn space_dash_with_hans(text: &str) -> String {
     return out;
 }
 
-pub fn is_ignore_auto_correct(raw: &str) -> bool {
-    let re = Regex::new(r"autocorrect:([ ]*)(0|false)").unwrap();
-    return re.is_match(raw);
-}
-
-// get file extension from filepath
-pub fn get_file_extension(filepath: &str) -> &str {
-    if let Some(ext) = Path::new(filepath).extension().and_then(OsStr::to_str) {
-        return ext;
-    }
-
-    return "";
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -245,22 +256,22 @@ mod tests {
         let cases = map![
             "!sm" => "!sm",
             "Hello world!" => "Hello world!",
-            "部署到 heroku 有问题网页不能显示" => "部署到 heroku 有问题网页不能显示",
-            "[北京] 美企聘 site/web 大型应用开发高手-Ruby" => "[北京] 美企聘 site/web 大型应用开发高手-Ruby",
-            "[成都](团 800) 招聘 Rails 工程师" => "[成都](团 800) 招聘 Rails 工程师",
-            "Teahour.fm 第 18 期发布" => "Teahour.fm 第 18 期发布",
-            "Yes！升级到了 Rails 4" => "Yes！升级到了 Rails 4",
-            "WWDC 上讲到的 Objective C/LLVM 改进" => "WWDC 上讲到的 Objective C/LLVM 改进",
-            "在 Ubuntu11.10 64 位系统安装 newrelic 出错" => "在 Ubuntu11.10 64 位系统安装 newrelic 出错",
-            "升级了 macOS 10.9 附遇到的 Bug 概率有 0.1% 或更少" => "升级了 macOS 10.9 附遇到的 Bug 概率有 0.1% 或更少",
-            "在做 Rails 3.2 Tutorial 第 Chapter 9.4.2 遇到一个问题求助！" => "在做 Rails 3.2 Tutorial 第 Chapter 9.4.2 遇到一个问题求助！",
-            "发现 macOS 安装软件新方法：Homebrew" => "发现 macOS 安装软件新方法：Homebrew",
+            "部署到heroku有问题网页不能显示" => "部署到 heroku 有问题网页不能显示",
+            "[北京]美企聘site/web大型应用开发高手-Ruby" => "[北京] 美企聘 site/web 大型应用开发高手-Ruby",
+            "[成都](团800)招聘Rails工程师" => "[成都](团 800) 招聘 Rails 工程师",
+            "Teahour.fm第18期发布" => "Teahour.fm 第 18 期发布",
+            "Yes!升级到了Rails 4" => "Yes！升级到了 Rails 4",
+            "WWDC上讲到的Objective C/LLVM改进" => "WWDC 上讲到的 Objective C/LLVM 改进",
+            "在Ubuntu11.10 64位系统安装newrelic出错" => "在 Ubuntu11.10 64 位系统安装 newrelic 出错",
+            "升级了macOS 10.9 附遇到的Bug概率有0.1%或更少" => "升级了 macOS 10.9 附遇到的 Bug 概率有 0.1% 或更少",
+            "在做Rails 3.2 Tutorial第Chapter 9.4.2遇到一个问题求助！" => "在做 Rails 3.2 Tutorial 第 Chapter 9.4.2 遇到一个问题求助！",
+            "发现macOS安装软件新方法：Homebrew" => "发现 macOS 安装软件新方法：Homebrew",
             "without looking like it’s been marked up with tags or formatting instructions." => "without looking like it’s been marked up with tags or formatting instructions.",
-            "隔夜 SHIBOR 报 1.5530%，上涨 33.80 个基点。7 天 SHIBOR 报 2.3200%，上涨 6.10 个基点。3 个月 SHIBOR 报 2.8810%，下降 1.80 个" => "隔夜 SHIBOR 报 1.5530%，上涨 33.80 个基点。7 天 SHIBOR 报 2.3200%，上涨 6.10 个基点。3 个月 SHIBOR 报 2.8810%，下降 1.80 个",
-            "野村：重申吉利汽车 (00175)“买入” 评级 上调目标价至 17.9 港元" => "野村：重申吉利汽车 (00175)“买入” 评级 上调目标价至 17.9 港元",
-            "小米集团-W 调整目标价为 13.5 港币" => "小米集团-W 调整目标价为 13.5 港币",
-            "（路透社）- 预计全年净亏损约 1.3 亿港元 * 预期因出售汽车" => "（路透社）- 预计全年净亏损约 1.3 亿港元 * 预期因出售汽车",
-            "（路透社）- 预计全年净亏损约 1.3 亿\n\n 港元 * 预期因出售汽车" => "（路透社）- 预计全年净亏损约 1.3 亿\n\n 港元 * 预期因出售汽车"
+            "隔夜SHIBOR报1.5530%，上涨33.80%个基点。7天SHIBOR报2.3200%，上涨6.10个基点。3个月SHIBOR报2.8810%，下降1.80个" => "隔夜 SHIBOR 报 1.5530%，上涨 33.80% 个基点。7 天 SHIBOR 报 2.3200%，上涨 6.10 个基点。3 个月 SHIBOR 报 2.8810%，下降 1.80 个",
+            "野村：重申吉利汽车(00175)“买入”评级 上调目标价至17.9港元" => "野村：重申吉利汽车 (00175)“买入” 评级 上调目标价至 17.9 港元",
+            "小米集团-W调整目标价为13.5港币" => "小米集团-W 调整目标价为 13.5 港币",
+            "（路透社）-预计全年净亏损约1.3亿港元*预期因出售汽车" => "（路透社）- 预计全年净亏损约 1.3 亿港元 * 预期因出售汽车",
+            "（路透社）-预计全年净亏损约1.3亿\n\n港元*预期因出售汽车" => "（路透社）- 预计全年净亏损约 1.3 亿\n\n港元 * 预期因出售汽车"
         ];
 
         assert_cases(cases);
@@ -269,15 +280,27 @@ mod tests {
     #[test]
     fn it_format_for_specials() {
         let cases = map![
-            "记事本，记事本显示阅读次数#149" => "记事本，记事本显示阅读次数#149",
-            "HashTag 的演示 #标签" => "HashTag 的演示 #标签",
-            "HashTag 的演示 #标签# 演示" =>         "HashTag 的演示 #标签# 演示",
-            "Mention 里面有关于中文的 @某某人" =>        "Mention 里面有关于中文的 @某某人",
-            "里面用 @foo 符号的话后面的变量名会被替换成 userN" => "里面用 @foo 符号的话后面的变量名会被替换成 userN",
-            "Dollar 的演示 $阿里巴巴.US$ 股票标签" =>    "Dollar 的演示 $阿里巴巴.US$ 股票标签",
+            "记事本,记事本显示阅读次数#149" => "记事本，记事本显示阅读次数#149",
+            "HashTag的演示#标签" => "HashTag 的演示#标签",
+            "HashTag 的演示#标签#演示" =>         "HashTag 的演示#标签#演示",
+            "Mention里面有关于中文的@某某人" =>        "Mention 里面有关于中文的 @某某人",
+            "里面用@foo符号的话后面的变量名会被替换成userN" => "里面用 @foo 符号的话后面的变量名会被替换成 userN",
+            "Dollar的演示$阿里巴巴.US$股票标签" =>    "Dollar 的演示$阿里巴巴.US$股票标签",
             "测试英文,逗号Comma转换." =>    "测试英文，逗号 Comma 转换。",
-            "测试英文,Comma 逗号转换." =>    "测试英文，Comma 逗号转换。",
-            "英文, 逗号后面. 阿里巴巴.US有空格? 的情况! 测试" =>    "英文，逗号后面。阿里巴巴.US 有空格？的情况！测试"
+            "测试英文,Comma逗号转换." =>    "测试英文，Comma 逗号转换。",
+            "英文,逗号后面.阿里巴巴.US有空格?的情况!测试" =>    "英文，逗号后面。阿里巴巴.US 有空格？的情况！测试",
+            "search by%关键词%" => "search by%关键词%"
+        ];
+
+        assert_cases(cases);
+    }
+
+    #[test]
+    fn it_format_for_programming() {
+        let cases = map![
+            "内容带有\n不会处理" => "内容带有\n不会处理",
+            "内容带有%s或%d或%v特殊字符，或者%S或%D或%V这些特殊format字符" => "内容带有%s或%d或%v特殊字符，或者%S或%D或%V这些特殊 format 字符",
+            "内容带有$1或$2或$3特殊字符" => "内容带有$1或$2或$3特殊字符"
         ];
 
         assert_cases(cases);
@@ -286,14 +309,14 @@ mod tests {
     #[test]
     fn it_format_for_date() {
         let cases = map![
-            "于 3 月 10 日开始" => "于 3 月 10 日开始",
-            "于 3 月开始" =>    "于 3 月开始",
-            "于 2009 年开始" => "于 2009 年开始",
-            "正式发布2013年3月10日-Ruby Saturday 活动召集" => "正式发布 2013 年 3 月 10 日-Ruby Saturday 活动召集",
+            "于3月10日开始" => "于 3 月 10 日开始",
+            "于3月开始" =>    "于 3 月开始",
+            "于2009年开始" => "于 2009 年开始",
+            "正式发布2013年3月10日-Ruby Saturday活动召集" => "正式发布 2013 年 3 月 10 日-Ruby Saturday 活动召集",
             "正式发布2013年3月10号发布" =>                 "正式发布 2013 年 3 月 10 号发布",
             "2013年12月22号开始出发" =>                  "2013 年 12 月 22 号开始出发",
-            "12 月 22 号开始出发" =>                       "12 月 22 号开始出发",
-            "22 号开始出发" =>                          "22 号开始出发"
+            "12月22号开始出发" =>                       "12 月 22 号开始出发",
+            "22号开始出发" =>                          "22 号开始出发"
         ];
 
         assert_cases(cases);
@@ -311,9 +334,9 @@ mod tests {
     #[test]
     fn it_format_for_number() {
         let cases = map![
-            "在 Ubuntu 11.10 64 位系统安装 Go 出错" => "在 Ubuntu 11.10 64 位系统安装 Go 出错",
-            "喜欢暗黑 2 却对 D3 不满意的可以看看这个。" =>     "喜欢暗黑 2 却对 D3 不满意的可以看看这个。",
-            "Ruby 2.7 版本第 3 次发布"=>          "Ruby 2.7 版本第 3 次发布"
+            "在Ubuntu 11.10 64位系统安装Go出错" => "在 Ubuntu 11.10 64 位系统安装 Go 出错",
+            "喜欢暗黑2却对 D3不满意的可以看看这个。" =>     "喜欢暗黑 2 却对 D3 不满意的可以看看这个。",
+            "Ruby 2.7版本第3次发布"=>          "Ruby 2.7 版本第 3 次发布"
         ];
 
         assert_cases(cases);
@@ -322,10 +345,10 @@ mod tests {
     #[test]
     fn it_format_for_special_symbols() {
         let cases = map![
-            "公告:(美股) 阿里巴巴 [BABA.US] 发布 2019 下半年财报！" =>          "公告:(美股) 阿里巴巴 [BABA.US] 发布 2019 下半年财报！",
-            "消息 http://github.com 解禁了" =>                     "消息 http://github.com 解禁了",
-            "美股异动 | 阿帕奇石油 (APA.US) 盘前涨超 15% 在苏里南近海发现大量石油" =>     "美股异动 | 阿帕奇石油 (APA.US) 盘前涨超 15% 在苏里南近海发现大量石油",
-            "美国统计局：美国 11 月原油出口下降至 302.3 万桶/日，10 月为 338.3 万桶/日。" => "美国统计局：美国 11 月原油出口下降至 302.3 万桶/日，10 月为 338.3 万桶/日。",
+            "公告:(美股)阿里巴巴[BABA.US]发布2019下半年财报!" =>          "公告:(美股) 阿里巴巴 [BABA.US] 发布 2019 下半年财报！",
+            "消息http://github.com解禁了" =>                     "消息 http://github.com 解禁了",
+            "美股异动|阿帕奇石油(APA.US)盘前涨超15% 在苏里南近海发现大量石油" =>     "美股异动 | 阿帕奇石油 (APA.US) 盘前涨超 15% 在苏里南近海发现大量石油",
+            "美国统计局：美国11月原油出口下降至302.3万桶/日，10月为338.3万桶/日。" => "美国统计局：美国 11 月原油出口下降至 302.3 万桶/日，10 月为 338.3 万桶/日。",
             "[b]Foo bar dar[/b]" => "[b]Foo bar dar[/b]"
         ];
 
@@ -335,8 +358,8 @@ mod tests {
     #[test]
     fn it_format_for_fullwidth_symbols() {
         let cases = map![
-            "（美股）市场：发布「最新」100 消息【BABA.US】“大涨”50%；同比上涨 20%！" => "（美股）市场：发布「最新」100 消息【BABA.US】“大涨”50%；同比上涨 20%！",
-            "第 3 季度财报发布看涨看跌？敬请期待。" =>                         "第 3 季度财报发布看涨看跌？敬请期待。"
+            "（美股）市场：发布「最新」100消息【BABA.US】“大涨”50%；同比上涨20%！" => "（美股）市场：发布「最新」100 消息【BABA.US】“大涨”50%；同比上涨 20%！",
+            "第3季度财报发布看涨看跌？敬请期待。" =>                         "第 3 季度财报发布看涨看跌？敬请期待。"
         ];
 
         assert_cases(cases);
@@ -345,14 +368,14 @@ mod tests {
     #[test]
     fn it_format_for_space_dash_with_hans() {
         let cases = map![
-            "第 3 季度 - 财报发布看涨看跌？敬请期待。" => "第 3 季度 - 财报发布看涨看跌？敬请期待。",
+            "第3季度-财报发布看涨看跌？敬请期待。" => "第 3 季度 - 财报发布看涨看跌？敬请期待。",
             "腾讯-ADR-已发行" =>     "腾讯-ADR-已发行",
-            "（腾讯）- 发布 -（新版）本微信" => "（腾讯）- 发布 -（新版）本微信",
-            "【腾讯】- 发布 -【新版】本微信" => "【腾讯】- 发布 -【新版】本微信",
-            "「腾讯」- 发布 -「新版」本微信" => "「腾讯」- 发布 -「新版」本微信",
-            "《腾讯》- 发布 -《新版》本微信" => "《腾讯》- 发布 -《新版》本微信",
-            "“腾讯” - 发布 - “新版” 本微信" => "“腾讯” - 发布 - “新版” 本微信",
-            "‘腾讯’ - 发布 - ‘新版’ 本微信" => "‘腾讯’ - 发布 - ‘新版’ 本微信"
+            "（腾讯）-发布-（新版）本微信" => "（腾讯）- 发布 -（新版）本微信",
+            "【腾讯】-发布-【新版】本微信" => "【腾讯】- 发布 -【新版】本微信",
+            "「腾讯」-发布-「新版」本微信" => "「腾讯」- 发布 -「新版」本微信",
+            "《腾讯》-发布-《新版》本微信" => "《腾讯》- 发布 -《新版》本微信",
+            "“腾讯”-发布-“新版”本微信" => "“腾讯” - 发布 - “新版” 本微信",
+            "‘腾讯’-发布-‘新版’本微信" => "‘腾讯’ - 发布 - ‘新版’ 本微信"
         ];
 
         assert_cases(cases);
@@ -361,44 +384,12 @@ mod tests {
     #[test]
     fn it_format_for_cjk() {
         let cases = map![
-            "全世界已有数百家公司在生产环境中使用 Rust，以达到快速、跨平台、低资源占用的目的。很多著名且受欢迎的软件，例如 Firefox、 Dropbox 和 Cloudflare 都在使用 Rust。" => "全世界已有数百家公司在生产环境中使用 Rust，以达到快速、跨平台、低资源占用的目的。很多著名且受欢迎的软件，例如 Firefox、 Dropbox 和 Cloudflare 都在使用 Rust。",
-            "現今全世界上百家公司企業為了尋求快速、節約資源而且能跨平台的解決辦法，都已在正式環境中使用 Rust。許多耳熟能詳且受歡迎的軟體，諸如 Firefox、Dropbox 以及 Cloudflare 都在使用 Rust。" => "現今全世界上百家公司企業為了尋求快速、節約資源而且能跨平台的解決辦法，都已在正式環境中使用 Rust。許多耳熟能詳且受歡迎的軟體，諸如 Firefox、Dropbox 以及 Cloudflare 都在使用 Rust。",
-            "既に、世界中の数百という企業が Rust を採用し、高速で低リソースのクロスプラットフォームソリューションを実現しています。皆さんがご存じで愛用しているソフトウェア、例えば Firefox、Dropbox や Cloudflare も、Rust を採用しています。" => "既に、世界中の数百という企業が Rust を採用し、高速で低リソースのクロスプラットフォームソリューションを実現しています。皆さんがご存じで愛用しているソフトウェア、例えば Firefox、Dropbox や Cloudflare も、Rust を採用しています。",
-            "전 세계 수백 개의 회사가 프로덕션 환경에서 Rust 를 사용하여 빠르고， 크로스 플랫폼 및 낮은 리소스 사용량을 달성했습니다. Firefox, Dropbox 및 Cloudflare 와 같이 잘 알려져 있고 널리 사용되는 많은 소프트웨어가 Rust 를 사용하고 있습니다." => "전 세계 수백 개의 회사가 프로덕션 환경에서 Rust 를 사용하여 빠르고， 크로스 플랫폼 및 낮은 리소스 사용량을 달성했습니다. Firefox, Dropbox 및 Cloudflare 와 같이 잘 알려져 있고 널리 사용되는 많은 소프트웨어가 Rust 를 사용하고 있습니다。"
+            "全世界已有数百家公司在生产环境中使用Rust，以达到快速、跨平台、低资源占用的目的。很多著名且受欢迎的软件，例如Firefox、 Dropbox和Cloudflare都在使用Rust。" => "全世界已有数百家公司在生产环境中使用 Rust，以达到快速、跨平台、低资源占用的目的。很多著名且受欢迎的软件，例如 Firefox、 Dropbox 和 Cloudflare 都在使用 Rust。",
+            "現今全世界上百家公司企業為了尋求快速、節約資源而且能跨平台的解決辦法，都已在正式環境中使用Rust。許多耳熟能詳且受歡迎的軟體，諸如Firefox、Dropbox以及Cloudflare都在使用Rust。" => "現今全世界上百家公司企業為了尋求快速、節約資源而且能跨平台的解決辦法，都已在正式環境中使用 Rust。許多耳熟能詳且受歡迎的軟體，諸如 Firefox、Dropbox 以及 Cloudflare 都在使用 Rust。",
+            "既に、世界中の数百という企業がRustを採用し、高速で低リソースのクロスプラットフォームソリューションを実現しています。皆さんがご存じで愛用しているソフトウェア、例えばFirefox、DropboxやCloudflareも、Rustを採用しています。" => "既に、世界中の数百という企業が Rust を採用し、高速で低リソースのクロスプラットフォームソリューションを実現しています。皆さんがご存じで愛用しているソフトウェア、例えば Firefox、Dropbox や Cloudflare も、Rust を採用しています。",
+            "전 세계 수백 개의 회사가 프로덕션 환경에서 Rust를 사용하여 빠르고, 크로스 플랫폼 및 낮은 리소스 사용량을 달성했습니다. Firefox, Dropbox 및 Cloudflare와 같이 잘 알려져 있고 널리 사용되는 많은 소프트웨어가 Rust를 사용하고 있습니다." => "전 세계 수백 개의 회사가 프로덕션 환경에서 Rust 를 사용하여 빠르고，크로스 플랫폼 및 낮은 리소스 사용량을 달성했습니다. Firefox, Dropbox 및 Cloudflare 와 같이 잘 알려져 있고 널리 사용되는 많은 소프트웨어가 Rust 를 사용하고 있습니다。"
         ];
 
         assert_cases(cases);
     }
-
-    #[test]
-    fn is_is_ignore_auto_correct() {
-        assert_eq!(
-            true,
-            is_ignore_auto_correct("# autocorrect: false\nHello world")
-        );
-        assert_eq!(
-            true,
-            is_ignore_auto_correct("# autocorrect:false\nHello world")
-        );
-        assert_eq!(
-            true,
-            is_ignore_auto_correct("# autocorrect: 0\nHello world")
-        );
-        assert_eq!(
-            false,
-            is_ignore_auto_correct("# autocorrect: 1\nHello world")
-        );
-        assert_eq!(
-            false,
-            is_ignore_auto_correct("# autocorrect: true\nHello world")
-        );
-        assert_eq!(false, is_ignore_auto_correct("Hello world"));
-    }
-
-    #[test]
-    fn is_get_file_extension() {
-        assert_eq!("rb", get_file_extension("/foo/bar/dar.rb"));
-        assert_eq!("js", get_file_extension("/dar.js"));
-        assert_eq!("", get_file_extension("/foo/bar/dar"));
-    }
 }
