@@ -4,30 +4,30 @@ use pest::Parser as P;
 use pest_derive::Parser;
 
 #[derive(Parser)]
-#[grammar = "grammar/swift.pest"]
+#[grammar = "../grammar/swift.pest"]
 struct SwiftParser;
 
 #[allow(dead_code)]
 pub fn format_swift(text: &str) -> code::FormatResult {
-    let pairs = SwiftParser::parse(Rule::item, text);
-    let text = code::FormatResult::new(text);
-    return code::format_pairs(text, pairs);
+  let pairs = SwiftParser::parse(Rule::item, text);
+  let text = code::FormatResult::new(text);
+  return code::format_pairs(text, pairs);
 }
 
 #[allow(dead_code)]
 pub fn lint_swift(text: &str) -> code::LintResult {
-    let pairs = SwiftParser::parse(Rule::item, text);
-    let text = code::LintResult::new(text);
-    return code::format_pairs(text, pairs);
+  let pairs = SwiftParser::parse(Rule::item, text);
+  let text = code::LintResult::new(text);
+  return code::format_pairs(text, pairs);
 }
 
 #[cfg(test)]
 mod tests {
-    use super::*;
+  use super::*;
 
-    #[test]
-    fn it_format_swift() {
-        let example = r###"
+  #[test]
+  fn it_format_swift() {
+    let example = r###"
 // 第1行注释
 // 第2行注释
 func helloWorld(name: String) -> String {
@@ -38,10 +38,12 @@ func helloWorld(name: String) -> String {
 这是多行string里面包含"双引号"
 "Begin at the beginning," the King said gravely.
 """
+
+  let re = try! NSRegularExpression(pattern:    "re正则")
 }
 "###;
 
-        let expect = r###"
+    let expect = r###"
 // 第 1 行注释
 // 第 2 行注释
 func helloWorld(name: String) -> String {
@@ -52,9 +54,11 @@ func helloWorld(name: String) -> String {
 这是多行 string 里面包含"双引号"
 "Begin at the beginning," the King said gravely.
 """
+
+  let re = try! NSRegularExpression(pattern:    "re正则")
 }
 "###;
 
-        assert_eq!(expect, format_swift(example).to_string());
-    }
+    assert_eq!(expect, format_swift(example).to_string());
+  }
 }
